pub struct CustomManifoldWrapper { /* private fields */ }Expand description
Wrapper for custom manifold learners to integrate with sklearn-style API
Implementations
Sourceimpl CustomManifoldWrapper
impl CustomManifoldWrapper
Sourcepub fn new(
plugin_name: &str,
params: Option<&PluginParameters>,
) -> SklResult<Self>
pub fn new( plugin_name: &str, params: Option<&PluginParameters>, ) -> SklResult<Self>
Create a new wrapper for a custom manifold learner
Sourcepub fn learner(&self) -> &dyn CustomManifoldLearner
pub fn learner(&self) -> &dyn CustomManifoldLearner
Get the underlying learner
Sourcepub fn learner_mut(&mut self) -> &mut dyn CustomManifoldLearner
pub fn learner_mut(&mut self) -> &mut dyn CustomManifoldLearner
Get mutable access to the underlying learner
Sourcepub fn plugin_name(&self) -> &str
pub fn plugin_name(&self) -> &str
Get the plugin name